@@ -1,8 +1,9 @@
 package Mail::DMARC::Policy;
-our $VERSION = '1.20191004'; # VERSION
 use strict;
 use warnings;
 
+our $VERSION = '1.20191025';
+
 use Carp;
 
 use Mail::DMARC::Report::URI;
@@ -184,7 +185,7 @@ sub is_valid {
 
 1;
 
-# ABSTRACT: a DMARC policy in object format
+__END__
 
 =pod
 
@@ -194,7 +195,7 @@ Mail::DMARC::Policy - a DMARC policy in object format
 
 =head1 VERSION
 
-version 1.20191004
+version 1.20191025
 
 =head1 SYNOPSIS
 
@@ -441,17 +442,18 @@ Matt Simerson <msimerson@cpan.org>
 
 Davide Migliavacca <shari@cpan.org>
 
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Matt Simerson.
+This software is copyright (c) 2019 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-__END__
-sub {}
-
