@@ -1,8 +1,9 @@
 package Mail::DMARC::Report;
-our $VERSION = '1.20191004'; # VERSION
 use strict;
 use warnings;
 
+our $VERSION = '1.20191025';
+
 use Carp;
 use IO::Compress::Gzip;
 use IO::Compress::Zip;
@@ -79,7 +80,7 @@ sub save_aggregate {
 
 1;
 
-# ABSTRACT: A DMARC report interface
+__END__
 
 =pod
 
@@ -89,7 +90,7 @@ Mail::DMARC::Report - A DMARC report interface
 
 =head1 VERSION
 
-version 1.20191004
+version 1.20191025
 
 =head1 DESCRIPTION
 
@@ -221,17 +222,18 @@ Matt Simerson <msimerson@cpan.org>
 
 Davide Migliavacca <shari@cpan.org>
 
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Matt Simerson.
+This software is copyright (c) 2019 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-__END__
-sub {}
-
