@@ -1,8 +1,9 @@
 package Mail::DMARC::Report::Aggregate;
-our $VERSION = '1.20191004'; # VERSION
 use strict;
 use warnings;
 
+our $VERSION = '1.20191025';
+
 use Carp;
 use Data::Dumper;
 use XML::LibXML;
@@ -187,7 +188,8 @@ sub get_policy_evaluated_as_xml {
 }
 
 1;
-# ABSTRACT: aggregate report object
+
+__END__
 
 =pod
 
@@ -197,7 +199,7 @@ Mail::DMARC::Report::Aggregate - aggregate report object
 
 =head1 VERSION
 
-version 1.20191004
+version 1.20191025
 
 =head1 DESCRIPTION
 
@@ -317,17 +319,18 @@ Matt Simerson <msimerson@cpan.org>
 
 Davide Migliavacca <shari@cpan.org>
 
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Matt Simerson.
+This software is copyright (c) 2019 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-__END__
-sub {}
-
