@@ -1,5 +1,5 @@
 package Mail::DMARC::Report::Aggregate::Record;
-our $VERSION = '1.20191004'; # VERSION
+our $VERSION = '1.20191025';
 use strict;
 use warnings;
 
@@ -72,8 +72,6 @@ sub row {
 
 1;
 
-# ABSTRACT: record section of aggregate report
-
 __END__
 
 =pod
@@ -84,7 +82,7 @@ Mail::DMARC::Report::Aggregate::Record - record section of aggregate report
 
 =head1 VERSION
 
-version 1.20191004
+version 1.20191025
 
 =head1 DESCRIPTION
 
@@ -102,11 +100,15 @@ Matt Simerson <msimerson@cpan.org>
 
 Davide Migliavacca <shari@cpan.org>
 
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Matt Simerson.
+This software is copyright (c) 2019 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
