@@ -1,5 +1,5 @@
 package Mail::DMARC::Report::Aggregate::Record::Auth_Results::DKIM;
-our $VERSION = '1.20191004'; # VERSION
+our $VERSION = '1.20191025';
 use strict;
 
 use Carp;
@@ -65,7 +65,7 @@ sub is_valid {
     my $self = shift;
 
     foreach my $f (qw/ domain result /) {
-        if ( !$self->{$f} ) {
+        if ( ! defined $self->{$f} ) {
             croak "DKIM value $f is required!";
         }
     }
@@ -74,8 +74,6 @@ sub is_valid {
 
 1;
 
-# ABSTRACT: auth_results/dkim section of a DMARC aggregate record
-
 __END__
 
 =pod
@@ -86,7 +84,7 @@ Mail::DMARC::Report::Aggregate::Record::Auth_Results::DKIM - auth_results/dkim s
 
 =head1 VERSION
 
-version 1.20191004
+version 1.20191025
 
 =head1 AUTHORS
 
@@ -100,13 +98,18 @@ Matt Simerson <msimerson@cpan.org>
 
 Davide Migliavacca <shari@cpan.org>
 
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Matt Simerson.
+This software is copyright (c) 2019 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
