@@ -1,5 +1,5 @@
 package Mail::DMARC::Report::Aggregate::Record::Auth_Results::SPF;
-our $VERSION = '1.20191004'; # VERSION
+our $VERSION = '1.20191025';
 use strict;
 
 use Carp;
@@ -64,7 +64,10 @@ sub is_valid {
 
     foreach my $f (qw/ domain result scope /) {
         next if $self->{$f};
-        warn "SPF $f is required but missing!\n";
+        if ($f ne 'scope') {
+            # quite a few DMARC reporters don't include scope
+            warn "SPF $f is required but missing!\n";
+        }
         return 0;
     }
 
@@ -78,8 +81,6 @@ sub is_valid {
 
 1;
 
-# ABSTRACT: auth_results/spf section of a DMARC aggregate record
-
 __END__
 
 =pod
@@ -90,7 +91,7 @@ Mail::DMARC::Report::Aggregate::Record::Auth_Results::SPF - auth_results/spf sec
 
 =head1 VERSION
 
-version 1.20191004
+version 1.20191025
 
 =head1 AUTHORS
 
@@ -104,13 +105,18 @@ Matt Simerson <msimerson@cpan.org>
 
 Davide Migliavacca <shari@cpan.org>
 
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Matt Simerson.
+This software is copyright (c) 2019 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
