@@ -1,8 +1,9 @@
 package Mail::DMARC::Report::Send::HTTP;
-our $VERSION = '1.20191004'; # VERSION
 use strict;
 use warnings;
 
+our $VERSION = '1.20191025';
+
 use Carp;
 
 #use Data::Dumper;
@@ -40,7 +41,7 @@ sub post {
 
 1;
 
-# ABSTRACT: utility methods to send reports by HTTP
+__END__
 
 =pod
 
@@ -50,7 +51,7 @@ Mail::DMARC::Report::Send::HTTP - utility methods to send reports by HTTP
 
 =head1 VERSION
 
-version 1.20191004
+version 1.20191025
 
 =head1 12.2.2. HTTP
 
@@ -78,17 +79,18 @@ Matt Simerson <msimerson@cpan.org>
 
 Davide Migliavacca <shari@cpan.org>
 
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Matt Simerson.
+This software is copyright (c) 2019 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-__END__
-sub {}
-
