@@ -1,8 +1,9 @@
 package Mail::DMARC::Report::Send::SMTP;
-our $VERSION = '1.20191004'; # VERSION
 use strict;
 use warnings;
 
+our $VERSION = '1.20191025';
+
 use Carp;
 use English '-no_match_vars';
 use Email::MIME;
@@ -234,7 +235,7 @@ sub get_helo_hostname {
 
 1;
 
-# ABSTRACT: utility methods for sending reports via SMTP
+__END__
 
 =pod
 
@@ -244,7 +245,7 @@ Mail::DMARC::Report::Send::SMTP - utility methods for sending reports via SMTP
 
 =head1 VERSION
 
-version 1.20191004
+version 1.20191025
 
 =head2 SUBJECT FIELD
 
@@ -318,17 +319,18 @@ Matt Simerson <msimerson@cpan.org>
 
 Davide Migliavacca <shari@cpan.org>
 
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Matt Simerson.
+This software is copyright (c) 2019 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-__END__
-sub {}
-
