@@ -1,8 +1,9 @@
 package Mail::DMARC::Report::URI;
-our $VERSION = '1.20191004'; # VERSION
 use strict;
 use warnings;
 
+our $VERSION = '1.20191025';
+
 use Carp;
 use URI;
 
@@ -58,7 +59,7 @@ sub get_size_limit {
 
 1;
 
-# ABSTRACT: a DMARC report URI
+__END__
 
 =pod
 
@@ -68,7 +69,7 @@ Mail::DMARC::Report::URI - a DMARC report URI
 
 =head1 VERSION
 
-version 1.20191004
+version 1.20191025
 
 =head1 SYNOPSIS
 
@@ -145,17 +146,18 @@ Matt Simerson <msimerson@cpan.org>
 
 Davide Migliavacca <shari@cpan.org>
 
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Matt Simerson.
+This software is copyright (c) 2019 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-__END__
-sub {}
-
